procedure: Display lines representing each procedure

Description Usage Arguments Examples

Description

Given a data.frame containing a list of SIDs, STARs, Approaches, and Enroute procedures, create a plot. Currently only IF, TF, and RF legs are supported. HM legs are removed. If there are still unsupported leg types, the first continous subset of known leg types is plotted.

If plotting more than one procedure you will generally want to specify the group aesthetic as group=paste(procedure, transistion)

stat_procedure and geom_procedure understand the following aesthetics. Required aesthetics are in bold and if RF legs are present the italicized aesthetics are also required.

Usage

 1
 2
 3
 4
 5
 6
 7
 8
 9
10
11
12
13
14
15
16
17
18
19
20
geom_procedure(
  mapping = NULL,
  data = NULL,
  position = "identity",
  na.rm = FALSE,
  show.legend = NA,
  inherit.aes = TRUE,
  ...
)

stat_procedure(
  mapping = NULL,
  data = NULL,
  geom = "path",
  position = "identity",
  na.rm = FALSE,
  show.legend = NA,
  inherit.aes = TRUE,
  ...
)

Arguments

mapping

Set of aesthetic mappings created by aes or aes_. If specified and inherit.aes = TRUE (the default), it is combined with the default mapping at the top level of the plot. You must supply mapping if there is no plot mapping.

data

The data to be displayed in this layer. There are three options:

If NULL, the default, the data is inherited from the plot data as specified in the call to ggplot.

A data.frame, or other object, will override the plot data. All objects will be fortified to produce a data frame. See fortify for which variables will be created.

A function will be called with a single argument, the plot data. The return value must be a data.frame., and will be used as the layer data.

position

Position adjustment, either as a string, or the result of a call to a position adjustment function.

na.rm

logical. Should this layer remove NA values

inherit.aes

If FALSE, overrides the default aesthetics, rather than combining with them. This is most useful for helper functions that define both data and aesthetics and shouldn't inherit behaviour from the default plot specification, e.g. borders.

...

Additional parameters to the geom and stat.

geom

The geometric object to use display the data

show.legnd

logical. Should this layer be included in the legends? NA, the default, includes if any aesthetics are mapped. FALSE never includes, and TRUE always includes.

Examples

1
2
3
4
5
6
## Not run: 
# given some procedure data with the latitude, longitude, procedure/transition names, and ARINC424 leg types
library(ggplot2)
ggplot(procs, aes(y=latitude, x=longitude, group=paste(procedure, transition), leg_type=leg_type)) + geom_procedure()

## End(Not run)

mitre/aviationgeoms documentation built on Sept. 15, 2020, 3:14 a.m.