Description Usage Arguments Examples
Given a data.frame containing a list of SIDs, STARs, Approaches, and Enroute procedures, create a plot. Currently only IF, TF, and RF legs are supported. HM legs are removed. If there are still unsupported leg types, the first continous subset of known leg types is plotted.
If plotting more than one procedure you will generally want to specify the group aesthetic as group=paste(procedure, transistion)
stat_procedure and geom_procedure understand the following aesthetics. Required aesthetics are in bold and if RF legs are present the italicized aesthetics are also required.
x
y
leg_type
rf_center_longitude
rf_center_latitude
turn_direction
alpha
colour
fill
linetype
size
1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 |
mapping |
Set of aesthetic mappings created by |
data |
The data to be displayed in this layer. There are three options: If A A |
position |
Position adjustment, either as a string, or the result of a call to a position adjustment function. |
na.rm |
logical. Should this layer remove NA values |
inherit.aes |
If |
... |
Additional parameters to the |
geom |
The geometric object to use display the data |
show.legnd |
logical. Should this layer be included in the legends?
|
1 2 3 4 5 6 | ## Not run:
# given some procedure data with the latitude, longitude, procedure/transition names, and ARINC424 leg types
library(ggplot2)
ggplot(procs, aes(y=latitude, x=longitude, group=paste(procedure, transition), leg_type=leg_type)) + geom_procedure()
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.